@@ -63,7 +63,8 @@ AddresseeLineEditPrivate::AddresseeLineEditPrivate(KPIM::AddresseeLineEdit *qq,
       m_enableBalooSearch(true),
       mExpandIntern(true),
       mAutoGroupExpand(false),
-      mShowRecentAddresses(true)
+      mShowRecentAddresses(true),
+      mCanDeleteLineEdit(true)
 {
     if (!s_networkConfigMgr) {
         s_networkConfigMgr = new QNetworkConfigurationManager(QCoreApplication::instance());
@@ -903,6 +904,16 @@ void AddresseeLineEditPrivate::slotConfigureBalooBlackList()
     delete dlg;
 }
 
+bool AddresseeLineEditPrivate::canDeleteLineEdit() const
+{
+    return mCanDeleteLineEdit;
+}
+
+void AddresseeLineEditPrivate::setCanDeleteLineEdit(bool inprogressToConfigureCompletion)
+{
+    mCanDeleteLineEdit = inprogressToConfigureCompletion;
+}
+
 KConfig *AddresseeLineEditPrivate::recentAddressConfig() const
 {
     return m_recentAddressConfig;
